try:
    from RPi.GPIO import GPIO
except:
    from .emulate import GPIO


class LightSensor(object):

    def __init__(self, pin):
        self._pin = pin
        GPIO.setmode(GPIO.BOARD)
        GPIO.setup(pin, GPIO.IN)
        self._callback = None

    def read(self):
        return GPIO.input(self._pin)

    def one_shot_lighting_change(self, callback):
        self._callback = callback
        GPIO.add_event_detect(self._pin, GPIO.BOTH, callback=self._one_shot_callback)

    def _one_shot_callback(self, pin):
        if self._callback is None:
            return
        input = 0
        for i in range(100):
            input += self.read()
        if input > 75: # 75% confidence there is light
            self._callback(True)
            self._callback = None
        if input < 25: # 75% confidence it is dark
            self._callback(False)


class GPIO(object):

    BOARD = 0

    IN = 0
    BOTH = 1

    count = 0

    @staticmethod
    def setup(*args):
        pass

    @staticmethod
    def setmode(*args):
        pass

    @staticmethod
    def input(pin):
        GPIO.count += 1
        if GPIO.count < 600 or GPIO.count > 5000:
            return 0
        else:
            return 1

    @staticmethod
    def add_event_detect(pin, which, callback):
        GPIO.count += 1
        import time, threading
        class T(threading.Thread):

            def run(self):
                while True:
                    time.sleep(2.0)
                    callback(pin)
        GPIO.t = T()
        GPIO.t.start()
